RemitsoTextStyle class abstract

Constructors

RemitsoTextStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

buttonText TextStyle
no setter
caption TextStyle
no setter
displayLarge TextStyle
no setter
no setter
header2 TextStyle
no setter
inputText TextStyle
no setter
subh1 TextStyle
no setter
subh2 TextStyle
no setter